@@ -61,11 +61,14 @@ def create_video(list_comp_data, path_video, job_id):
     max_real_duration=0 # thoi gian cua 1 video
     is_compilation=False
     audio_compilation_path=None
+    cnt_effect_vid=0
     for comp in arr_comps:
         if comp.type=="compilation":
             is_compilation=True
             audio_compilation_path=comp.get_audio()
             continue
+        if comp.type=="video":
+            cnt_effect_vid += 1
         if comp.type == "element":
             #audio_tmp = CompositeVideoClip(arr_composite.copy()).audio
             comp.set_bg_clip(CompositeVideoClip(arr_composite.copy()))
@@ -87,29 +90,37 @@ def create_video(list_comp_data, path_video, job_id):
         if audio_compilation_path is None:
             raise Exception("Audio Compulation Error!!!")
         cnt_real_duration=0
-        while max_real_duration < 60*2/3 and cnt_real_duration<2:
+        while max_real_duration < 60*2/3 and cnt_real_duration<2 and cnt_effect_vid>1:
             max_real_duration*=2
             cnt_real_duration+=1
         tmp_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) +".avi"
         tmp_path_maked_loop = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + ".avi"
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_real_duration)
-        final_clip.write_videofile(tmp_path, fps=24, codec='libx264',audio=False)
-        final_clip.close()
-        final_clip = VideoFileClip(tmp_path, audio=False)
-        cross = final_clip.duration / 5
-        if cross > 3:
-            cross = 3
-        clip = make_loopable.make_loopable(final_clip, cross)
-        clip.write_videofile(tmp_path_maked_loop, fps=24, codec='libx264',audio=False)
-        clip.close()
+        final_clip.write_videofile(tmp_path, fps=24, codec='libx264', audio=False, logger=logger)
         final_clip.close()
+        if cnt_effect_vid>1:
+            final_clip = VideoFileClip(tmp_path, audio=False)
+            cross = final_clip.duration / 5
+            if cross > 3:
+                cross = 3
+            clip = make_loopable.make_loopable(final_clip, cross)
+            clip.write_videofile(tmp_path_maked_loop, fps=24, codec='libx264', audio=False, logger=logger)
+            clip.close()
+            final_clip.close()
+        else:
+            tmp_path_maked_loop = tmp_path
         audio_compilation = AudioFileClip(audio_compilation_path)
         final_clip_path = create_loop(tmp_path_maked_loop, audio_compilation.duration)
-        os.remove(tmp_path_maked_loop)
-        os.remove(tmp_path)
+        try:
+            os.remove(tmp_path_maked_loop)
+        except:
+            pass
+        try:
+            os.remove(tmp_path)
+        except:
+            pass
         audio_compilation.close()
         create_video_audio(final_clip_path, audio_compilation_path, path_video)
-
     for comp in arr_comps:
         comp.close()
 
