@@ -17,7 +17,7 @@ def create_compilation_songs(data):
     #3: youtube_video
     #7: deezer
     #8: link direct
-    arr_songs=json.loads(data)
+    arr_songs=data
     file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
     file_merg = open(file_merg_path, "a")
     final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.mp3'
